@@ -1,5 +1,5 @@
-__version__ = "0.6.0"
-__keywords__ = ["thread wrapper class"]
+__version__ = "0.7.0"
+__keywords__ = ["thread wrapper class asyncio"]
 
 
 if not __version__.endswith(".0"):
@@ -11,4 +11,4 @@ if not __version__.endswith(".0"):
 
 
 from .core import *
-
+from ._async import *
